import QtQuick 2.5
import com.zuragon.Matlab 1.0
import com.zuragon.ViCANdo 1.0
import QtQuick.Controls 1.4

Rectangle {
    id: rectangle1
    width: 600
    height: 400
    color: "#e3d3a4"
    property int pendingCmdID : 0

    SourceEventListener {
        source: project.findObject("video0")

        onDataReceived: {
            if ( pendingCmdID !== 0 ) {
                //project.log("Command pending ...");
                return;
            }

            //project.log("Top video view onDataReceived: Send data to Matlab Engine to adjust the image.");
            engine.putVariable("image_a", data)
            pendingCmdID =  engine.evaluate("adjusted_image = imadjust(image_a,[.2 .3 0; .6 .7 1],[])");
            //pendingCmdID =  engine.evaluate("adjusted_image = rgb2gray(image_a)");
        }
    }

    MathEngine {
        id: engine

        onOutput: {
            outputArea.text = output
        }

        onCommandDone: {
            //project.log("Matlab Engine: Command done: " + id + " pending command: " + pendingCmdID)
            if ( id === pendingCmdID ) {
                //project.log("*** Matlab Engine: Command done: " + id + ", adjust the bottom video view.")
				// Get the results from Matlab engine and then use the result to adjust the bottom video view
                video_result.image = engine.arrayToImage("adjusted_image");
                pendingCmdID = 0;
            }
        }
    }

    TextArea {
        id: commandArea
        height: 81
        anchors.right: parent.horizontalCenter
        anchors.rightMargin: 8
        anchors.left: parent.left
        anchors.leftMargin: 8
        anchors.top: label1.bottom
        anchors.topMargin: 8
    }

    TextArea {
        id: outputArea
        anchors.right: parent.horizontalCenter
        anchors.rightMargin: 0
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 8
        anchors.left: parent.left
        anchors.leftMargin: 8
        anchors.top: evaluateButton.bottom
        anchors.topMargin: 8
    }

    Button {
        id: evaluateButton
        x: 165
        text: qsTr("Evaluate")
        anchors.right: commandArea.right
        anchors.rightMargin: 0
        anchors.top: commandArea.bottom
        anchors.topMargin: 8

        onClicked: {
            var id = engine.evaluate(commandArea.text)
            //console.log("Evaluate button clicked: Command id " + id)
        }

    }

    Button {
        id: testButton
        x: 165
        text: qsTr("Test")
        anchors.right: evaluateButton.left
        anchors.rightMargin: 8
        anchors.top: commandArea.bottom
        anchors.topMargin: 8
        onClicked: {
            engine.evaluate("a0 = 45.5")
            engine.evaluate("a1 = [1,2,3,4,5]")
            engine.evaluate("a2 = [1,2,3,4; 2,3,5,6]")
            var a0 = engine.arrayToVar("a0");
            var a1 = engine.arrayToVar("a1");
            var a2 = engine.arrayToVar("a2");

            project.log("a0 " + a0);
            project.log("a1 " + a1);
            project.log("a2 " + a2);
        }
    }

    Label {
        id: label1
        color: "#ffffff"
        text: qsTr("Matlab command:")
        anchors.left: parent.left
        anchors.leftMargin: 8
        anchors.top: parent.top
        anchors.topMargin: 8
    }

    VideoView {
        id: video0_view
        source:  project.findObject("video0")
        autoScaleVideo: true;
        centerVideo:  true;

        anchors.left: parent.horizontalCenter
        anchors.leftMargin: 8
        anchors.top: parent.top
        anchors.topMargin: 8
        anchors.right: parent.right
        anchors.rightMargin: 8
        anchors.bottom: parent.verticalCenter
        anchors.bottomMargin: 4
    }

    VideoView {
        id: video_result
        autoScaleVideo: true;
        centerVideo:  true;

        anchors.right: parent.right
        anchors.rightMargin: 8
        anchors.left: parent.horizontalCenter
        anchors.leftMargin: 8
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 8
        anchors.top: parent.verticalCenter
        anchors.topMargin: 4
    }
}
