import QtQuick 2.5
import com.zuragon.Matlab 1.0
import com.zuragon.ViCANdo 1.0
import QtQuick.Controls 1.4

Rectangle {
    id: rectangle1
    width: 600
    height: 400
    color: "#e3d3a4"
    property int pendingCmdID : 0

    SourceEventListener {
        source: project.findObject("video0")

        onDataReceived: {
            if ( pendingCmdID !== 0 ) {
                // project.log("Command pending ...");
                return;
            }

            // project.log(" do img adjust");
            engine.putVariable("image_a", data)
            pendingCmdID =  engine.evaluate("result_image = blobAnalysis(image_a)");
        }
    }

    MathEngine {
        id: engine

        onOutput: {
            outputArea.text = output
        }

        onCommandDone: {
            if ( id === pendingCmdID ) {
                video_result.image = engine.arrayToImage("result_image");
                pendingCmdID = 0;
            }
        }  

        Component.objectName: {
            engine.evaluate("yieldtag=imread('yieldtag1.jpg')")
            engine.evaluate("stptag=imread('yieldtag1.jpg')")
        }
    }

    TextArea {
        id: commandArea
        height: 81
        anchors.right: parent.horizontalCenter
        anchors.rightMargin: 8
        anchors.left: parent.left
        anchors.leftMargin: 8
        anchors.top: label1.bottom
        anchors.topMargin: 8
    }

    TextArea {
        id: outputArea
        anchors.right: parent.horizontalCenter
        anchors.rightMargin: 0
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 8
        anchors.left: parent.left
        anchors.leftMargin: 8
        anchors.top: evaluateButton.bottom
        anchors.topMargin: 8
    }

    Button {
        id: evaluateButton
        x: 165
        text: qsTr("Evaluate")
        anchors.right: commandArea.right
        anchors.rightMargin: 0
        anchors.top: commandArea.bottom
        anchors.topMargin: 8

        onClicked: {
            var id = engine.evaluate(commandArea.text)
            console.log("Command id " + id)
        }

    }

    Label {
        id: label1
        color: "black"
        text: qsTr("Matlab command:")
        anchors.left: parent.left
        anchors.leftMargin: 8
        anchors.top: parent.top
        anchors.topMargin: 8
    }

    VideoView {
        id: video0_view
        source:  project.findObject("video0")
        autoScaleVideo: true;
        centerVideo:  true;

        anchors.left: parent.horizontalCenter
        anchors.leftMargin: 8
        anchors.top: parent.top
        anchors.topMargin: 8
        anchors.right: parent.right
        anchors.rightMargin: 8
        anchors.bottom: parent.verticalCenter
        anchors.bottomMargin: 4

        Label {
            id: camera_label
            text: qsTr("Camera")

            anchors.top: parent.top
            anchors.topMargin: 8
            anchors.left: parent.left
            anchors.leftMargin: 8
       }
    }

    VideoView {
        id: video_result
        autoScaleVideo: true;
        centerVideo:  true;

        anchors.right: parent.right
        anchors.rightMargin: 8
        anchors.left: parent.horizontalCenter
        anchors.leftMargin: 8
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 8
        anchors.top: parent.verticalCenter
        anchors.topMargin: 4

        Label {
            id: matlab_processed_label
            text: qsTr("Matlab processed")

            anchors.top: parent.top
            anchors.topMargin: 8
            anchors.left: parent.left
            anchors.leftMargin: 8
        }
    }
}
